@@ -43,7 +43,7 @@ create_drake_spec <- function(
 
 # https://github.com/ropensci/drake/issues/887 # nolint
 cds_set_knitr_files <- function(args, spec) {
-  args$logger$minor("set knitr files")
+  args$logger$disk("set knitr files")
   knitr_files <- lightly_parallelize(
     X = spec,
     FUN = function(x) {
@@ -60,7 +60,7 @@ cds_set_knitr_files <- function(args, spec) {
 }
 
 cds_get_knitr_hash <- function(args, spec) {
-  args$logger$minor("get knitr hash")
+  args$logger$disk("get knitr hash")
   if (!args$cache$exists(key = "knitr", namespace = "memoize")) {
     out <- args$cache$digest("", serialize = FALSE)
     return(out)
@@ -68,7 +68,7 @@ cds_get_knitr_hash <- function(args, spec) {
   knitr_files <- args$cache$safe_get(key = "knitr", namespace = "memoize")
   knitr_hashes <- lightly_parallelize(
     X = knitr_files,
-    FUN = storage_hash,
+    FUN = static_storage_hash,
     jobs = args$jobs,
     config = args
   )
@@ -88,7 +88,7 @@ cds_imports_kernel <- function(args, imports) {
 }
 
 cds_prepare_imports <- function(args) {
-  args$logger$minor("analyze environment")
+  args$logger$disk("analyze environment")
   imports <- as.list(args$envir)
   cds_unload_conflicts(
     imports = names(imports),
@@ -103,18 +103,13 @@ cds_prepare_imports <- function(args) {
 cds_unload_conflicts <- function(imports, targets, envir, logger) {
   common <- intersect(imports, targets)
   if (length(common)) {
-    logger$major(
-      "unload",
-      "targets from environment:\n",
-      multiline_message(common),
-      sep = ""
-    )
+    logger$term("unloading", length(common), "targets from environment")
   }
   remove(list = common, envir = envir)
 }
 
 cds_analyze_imports <- function(args, imports) {
-  args$logger$minor("analyze imports")
+  args$logger$disk("analyze imports")
   names <-  names(imports)
   out <- lightly_parallelize(
     X = seq_along(imports),
@@ -136,14 +131,14 @@ cdl_analyze_import <- function(index, imports, names, args) {
     deps_build = cds_import_dependencies(
       expr = imports[[index]],
       exclude = name,
-      allowed_globals = args$ht_imports
+      restrict = args$ht_imports
     )
   )
   as_drake_spec(spec)
 }
 
 cds_analyze_commands <- function(args) {
-  args$logger$minor("analyze commands")
+  args$logger$disk("analyze commands")
   args$plan$imported <- FALSE
   if ("trigger" %in% colnames(args$plan)) {
     args$plan$trigger <- lapply(
@@ -156,11 +151,11 @@ cds_analyze_commands <- function(args) {
   names(spec) <- args$plan$target
   args$default_condition_deps <- cds_import_dependencies(
     args$trigger$condition,
-    allowed_globals = args$ht_globals
+    restrict = args$ht_globals
   )
   args$default_change_deps <- cds_import_dependencies(
     args$trigger$change,
-    allowed_globals = args$ht_globals
+    restrict = args$ht_globals
   )
   out <- lightly_parallelize(
     X = spec,
@@ -178,7 +173,7 @@ cds_prepare_spec <- function(args, spec) {
   spec$deps_build <- cds_command_dependencies(
     command = spec$command,
     exclude = spec$target,
-    allowed_globals = args$ht_globals
+    restrict = args$ht_globals
   )
   spec$deps_dynamic <- cds_dynamic_deps(
     spec$dynamic,
@@ -208,12 +203,12 @@ cds_prepare_spec <- function(args, spec) {
     spec$deps_condition <- cds_import_dependencies(
       spec$trigger$condition,
       exclude = spec$target,
-      allowed_globals = args$ht_globals
+      restrict = args$ht_globals
     )
     spec$deps_change <- cds_import_dependencies(
       spec$trigger$change,
       exclude = spec$target,
-      allowed_globals = args$ht_globals
+      restrict = args$ht_globals
     )
   }
   cds_no_dynamic_triggers(spec)
@@ -279,32 +274,21 @@ cds_no_dynamic_triggers_impl <- function(target, deps_dynamic, deps_trigger) {
 }
 
 cds_import_dependencies <- function(
-  expr, exclude = character(0), allowed_globals = NULL
+  expr, exclude = character(0), restrict = NULL
 ) {
-  deps <- analyze_code(
-    expr = expr,
-    exclude = exclude,
-    allowed_globals = allowed_globals
-  )
-  deps$file_out <- deps$strings <- NULL
-  select_nonempty(deps)
+  deps <- drake_deps(expr = expr, exclude = exclude, restrict = restrict)
+  deps$file_out <- deps$strings <- character(0)
+  deps
 }
 
 cds_command_dependencies <- function(
   command,
   exclude = character(0),
-  allowed_globals = NULL
+  restrict = NULL
 ) {
-  if (!length(command)) {
-    return()
-  }
-  deps <- analyze_code(
-    command,
-    exclude = exclude,
-    allowed_globals = allowed_globals
-  )
-  deps$strings <- NULL
-  select_nonempty(deps)
+  deps <- drake_deps(command, exclude = exclude, restrict = restrict)
+  deps$strings <- character(0)
+  deps
 }
 
 cds_dynamic_deps <- function(dynamic, target, args) {
