@@ -1,10 +1,34 @@
 drake_meta_ <- function(target, config) {
-  is_subtarget <- is_subtarget(target, config) %|||% FALSE
-  class <- ifelse(is_subtarget, "subtarget", "target")
-  class(target) <- class
-  out <- drake_meta_impl(target, config)
-  class(out) <- c("drake_meta", "drake")
-  out
+  if (exists(target, envir = config$meta, inherits = FALSE)) {
+    return(config$meta[[target]])
+  }
+  set_drake_meta(target, config)
+  config$meta[[target]]
+}
+
+drake_meta_old <- function(target, config) {
+  if (exists(target, envir = config$meta_old, inherits = FALSE)) {
+    return(config$meta_old[[target]])
+  }
+  set_drake_meta_old(target, config)
+  config$meta_old[[target]]
+}
+
+set_drake_meta <- function(target, config) {
+  class(target) <- drake_meta_class(target, config)
+  meta <- drake_meta_impl(target, config)
+  set_drake_meta_old(target, config)
+  meta <- subsume_old_meta(target, meta, config)
+  class(meta) <- c("drake_meta", "drake")
+  config$meta[[target]] <- meta
+  NULL
+}
+
+set_drake_meta_old <- function(target, config) {
+  if (target_exists(target, config)) {
+    meta_old <- config$cache$get(key = target, namespace = "meta")
+    config$meta_old[[target]] <- meta_old
+  }
 }
 
 #' @export
@@ -22,57 +46,122 @@ print.drake_meta <- function(x, ...) {
   min_str(list3)
 }
 
+drake_meta_class <- function(target, config) {
+  spec <- config$spec[[target]]
+  if (is_subtarget(target, config)) {
+    return("subtarget")
+  }
+  if (is_dynamic(target, config)) {
+    return("dynamic")
+  }
+  if (is_encoded_path(target)) {
+    return("imported_file")
+  }
+  is_imported <- is_encoded_namespaced(target) || (spec$imported %|||% TRUE)
+  if (is_imported) {
+    return("imported_object")
+  }
+  "static"
+}
+
 drake_meta_impl <- function(target, config) {
   UseMethod("drake_meta_impl")
 }
 
-drake_meta_impl.subtarget <- function(target, config) {
-  out <- list(
-    name = target,
-    target = target,
-    imported = FALSE,
-    isfile = FALSE,
-    seed = resolve_target_seed(target, config)
-  )
-  if (config$log_build_times) {
-    out$time_start <- proc_time()
-  }
-  out
-}
-
-drake_meta_impl.default <- function(target, config) {
+drake_meta_impl.imported_file <- function(target, config) { # nolint
   spec <- config$spec[[target]]
   meta <- list(
     name = target,
     target = target,
-    imported = spec$imported %|||% TRUE,
+    imported = TRUE,
+    isfile = TRUE,
+    format = "none",
+    dynamic = FALSE,
+    missing = target_missing(target, config)
+  )
+  path <- config$cache$decode_path(target)
+  meta$mtime <- storage_mtime(path)
+  meta$size_storage <- storage_size(path)
+  spec$trigger <- trigger(condition = TRUE)
+  meta <- decorate_trigger_meta(target, meta, spec, config)
+  meta
+}
+
+drake_meta_impl.imported_object <- function(target, config) { # nolint
+  spec <- config$spec[[target]]
+  meta <- list(
+    name = target,
+    target = target,
+    imported = TRUE,
+    isfile = FALSE,
+    dynamic = FALSE,
+    format = "none",
+    missing = target_missing(target, config),
+    file_out = spec$deps_build$file_out
+  )
+  spec$trigger <- trigger(condition = TRUE)
+  meta <- decorate_trigger_meta(target, meta, spec, config)
+  meta
+}
+
+drake_meta_impl.subtarget <- function(target, config) {
+  parent_spec <- config$spec[[subtarget_parent(target, config)]]
+  list(
+    name = target,
+    target = target,
+    imported = FALSE,
+    isfile = FALSE,
+    dynamic = FALSE,
+    format = parent_spec$format %||NA% "none",
+    seed = resolve_target_seed(target, config),
+    time_start = drake_meta_start(config),
+    trigger = as.list(parent_spec$trigger)
+  )
+}
+
+drake_meta_impl.dynamic <- function(target, config) {
+  spec <- config$spec[[target]]
+  meta <- list(
+    name = target,
+    target = target,
+    imported = FALSE,
+    isfile = FALSE,
+    dynamic = TRUE,
+    format = spec$format %||NA% "none",
+    missing = target_missing(target, config),
+    seed = resolve_target_seed(target, config),
+    time_start = drake_meta_start(config),
+    dynamic_dependency_hash = dynamic_dependency_hash(target, config),
+    max_expand = spec$max_expand %||NA% config$max_expand
+  )
+  decorate_trigger_meta(target, meta, spec, config)
+}
+
+drake_meta_impl.static <- function(target, config) {
+  spec <- config$spec[[target]]
+  meta <- list(
+    name = target,
+    target = target,
+    imported = FALSE,
+    isfile = FALSE,
+    dynamic = FALSE,
+    format = spec$format %||NA% "none",
     missing = target_missing(target, config),
     file_out = spec$deps_build$file_out,
-    format = spec$format %||NA% "none",
-    dynamic = is.call(spec$dynamic)
+    seed = resolve_target_seed(target, config),
+    time_start = drake_meta_start(config)
   )
-  if (config$log_build_times) {
-    meta$time_start <- proc_time()
-  }
-  if (meta$imported) {
-    meta$isfile <- is_encoded_path(target)
-    meta$trigger <- trigger(condition = TRUE)
-  } else {
-    meta$isfile <- FALSE
-    meta$trigger <- as.list(spec$trigger)
-    meta$seed <- resolve_target_seed(target, config)
-  }
-  # For imported files.
-  if (meta$isfile) {
-    path <- config$cache$decode_path(target)
-    meta$mtime <- storage_mtime(path)
-    meta$size_storage <- storage_size(path)
-  }
+  meta <- decorate_trigger_meta(target, meta, spec, config)
+  meta
+}
+
+decorate_trigger_meta <- function(target, meta, spec, config) {
+  meta$trigger <- as.list(spec$trigger)
   if (meta$trigger$command) {
     meta$command <- spec$command_standardized
   }
   if (meta$trigger$depend) {
-    meta$dependency_hash <- dependency_hash(target = target, config = config)
+    meta$dependency_hash <- static_dependency_hash(target, config)
   }
   if (meta$trigger$file) {
     meta$input_file_hash <- input_file_hash(target = target, config = config)
@@ -82,13 +171,57 @@ drake_meta_impl.default <- function(target, config) {
     try_load_deps(spec$deps_change$memory, config = config)
     meta$trigger$value <- eval(meta$trigger$change, config$envir_targets)
   }
-  if (is_dynamic(target, config)) {
-    meta$dynamic_dependency_hash <- dynamic_dependency_hash(target, config)
-    meta$max_expand <- config$max_expand
+  meta
+}
+
+subsume_old_meta <- function(target, meta, config) {
+  if (!is_dynamic(target, config)) {
+    class(target) <- meta$format
+    meta <- decorate_trigger_format_meta(target, meta, config)
   }
   meta
 }
 
+decorate_trigger_format_meta <- function(target, meta, config) {
+  UseMethod("decorate_trigger_format_meta")
+}
+
+decorate_trigger_format_meta.default <- function(target, meta, config) { # nolint
+  meta
+}
+
+decorate_trigger_format_meta.file <- function(target, meta, config) { # nolint
+  meta_old <- config$meta_old[[target]]
+  if (is.null(meta_old) || !meta$trigger$file) {
+    return(meta)
+  }
+  path <- as.character(meta_old$format_file_path)
+  new_mtime <- storage_mtime(path)
+  new_size <- storage_size(path)
+  hash <- as.character(meta_old$format_file_hash)
+  exists <- file.exists(path)
+  hash[!exists] <- ""
+  should_rehash <- exists & should_rehash_local(
+    size_threshold = rehash_storage_size_threshold,
+    new_mtime = new_mtime,
+    old_mtime = as.numeric(meta_old$format_file_time),
+    new_size = new_size,
+    old_size = as.numeric(meta_old$format_file_size)
+  )
+  hash[should_rehash] <- rehash_local(path[should_rehash], config)
+  meta$format_file_path <- path
+  meta$format_file_hash <- hash
+  meta$format_file_time <- new_mtime
+  meta$format_file_size <- new_size
+  meta
+}
+
+drake_meta_start <- function(config) {
+  if (config$log_build_times) {
+    proc_time()
+  }
+}
+
 target_missing <- function(target, config) {
   !target_exists(target, config)
 }
@@ -110,12 +243,17 @@ target_exists_single <- function(target, config) {
   ht_exists(ht = config$ht_target_exists, x = target)
 }
 
-target_exists_fast <- Vectorize(
+target_exists_fast_list <- Vectorize(
   target_exists_single,
   vectorize.args = "target",
   USE.NAMES = FALSE
 )
 
+target_exists_fast <- function(target, config) {
+  out <- target_exists_fast_list(target, config)
+  as.logical(out)
+}
+
 resolve_target_seed <- function(target, config) {
   seed <- config$spec[[target]]$seed
   if (is.null(seed) || is.na(seed)) {
@@ -139,7 +277,7 @@ integer_hash <- function(x, mod = .Machine$integer.max) {
   as.integer(type.convert(hexval) %% mod)
 }
 
-dependency_hash <- function(target, config) {
+static_dependency_hash <- function(target, config) {
   spec <- config$spec[[target]]
   x <- spec$deps_build
   deps <- c(x$globals, x$namespaced, x$loadd, x$readd)
@@ -199,7 +337,7 @@ input_file_hash <- function(
   }
   out <- config$cache$memo_hash(
     x = files,
-    fun = storage_hash,
+    fun = static_storage_hash,
     config = config,
     size_threshold = size_threshold
   )
@@ -219,7 +357,7 @@ output_file_hash <- function(
   }
   out <- vapply(
     X = files,
-    FUN = storage_hash,
+    FUN = static_storage_hash,
     FUN.VALUE = character(1),
     config = config,
     size_threshold = size_threshold
@@ -228,7 +366,7 @@ output_file_hash <- function(
   config$cache$digest(out, serialize = FALSE)
 }
 
-storage_hash <- function(
+static_storage_hash <- function(
   target,
   config,
   size_threshold = rehash_storage_size_threshold
@@ -238,16 +376,16 @@ storage_hash <- function(
   }
   file <- config$cache$decode_path(target)
   if (is_url(file)) {
-    return(rehash_storage(target = target, file = file, config = config))
+    return(rehash_static_storage(target, file, config))
   }
   if (!file.exists(file)) {
     return(NA_character_)
   }
   if (target_missing(target, config)) {
-    return(rehash_storage(target = target, file = file, config = config))
+    return(rehash_static_storage(target, file, config))
   }
   meta <- config$cache$get(key = target, namespace = "meta")
-  should_rehash <- should_rehash_storage(
+  should_rehash <- should_rehash_local(
     size_threshold = size_threshold,
     new_mtime = storage_mtime(file),
     old_mtime = as.numeric(meta$mtime %|||% -Inf),
@@ -256,12 +394,12 @@ storage_hash <- function(
   )
   ifelse(
     should_rehash,
-    rehash_storage(target = target, config = config),
+    rehash_static_storage(target = target, config = config),
     config$cache$get(key = target)
   )
 }
 
-should_rehash_storage <- function(
+should_rehash_local_impl <- function(
   size_threshold,
   new_mtime,
   old_mtime,
@@ -274,15 +412,44 @@ should_rehash_storage <- function(
   small || touched || resized
 }
 
+should_rehash_local_list <- Vectorize(
+  should_rehash_local_impl,
+  vectorize.args = c("new_mtime", "old_mtime", "new_size", "old_size"),
+  USE.NAMES = FALSE
+)
+
+should_rehash_local <- function(
+  size_threshold,
+  new_mtime,
+  old_mtime,
+  new_size,
+  old_size
+) {
+  out <- should_rehash_local_list(
+    size_threshold = size_threshold,
+    new_mtime = new_mtime,
+    old_mtime = old_mtime,
+    new_size = new_size,
+    old_size = old_size
+  )
+  as.logical(out)
+}
+
 rehash_storage_size_threshold <- 1e5
 rehash_storage_size_tol <- .Machine$double.eps ^ 0.5
 
+storage_mtime_impl <- function(x) {
+  ifelse(dir.exists(x), dir_mtime(x), file_mtime(x))
+}
+
+storage_mtime_list <- Vectorize(
+  storage_mtime_impl,
+  vectorize.args = "x",
+  USE.NAMES = FALSE
+)
+
 storage_mtime <- function(x) {
-  if (dir.exists(x)) {
-    dir_mtime(x)
-  } else {
-    file_mtime(x)
-  }
+  as.numeric(storage_mtime_list(x))
 }
 
 dir_mtime <- function(x) {
@@ -301,12 +468,18 @@ file_mtime <- function(x) {
   as.numeric(file.mtime(x))
 }
 
+storage_size_impl <- function(x) {
+  ifelse(dir.exists(x), dir_size(x), file_size(x))
+}
+
+storage_size_list <- Vectorize(
+  storage_size_impl,
+  vectorize.args = "x",
+  USE.NAMES = FALSE
+)
+
 storage_size <- function(x) {
-  if (dir.exists(x)) {
-    dir_size(x)
-  } else {
-    file_size(x)
-  }
+  as.numeric(storage_size_list(x))
 }
 
 dir_size <- function(x) {
@@ -329,7 +502,7 @@ file_size <- function(x) {
   }
 }
 
-rehash_storage <- function(target, file = NULL, config) {
+rehash_static_storage <- function(target, file = NULL, config) {
   if (!is_encoded_path(target)) {
     return(NA_character_)
   }
@@ -345,12 +518,18 @@ rehash_storage <- function(target, file = NULL, config) {
   rehash_local(file, config)
 }
 
+rehash_local_impl <- function(file, config) {
+  ifelse(dir.exists(file), rehash_dir(file, config), rehash_file(file, config))
+}
+
+rehash_local_list <- Vectorize(
+  rehash_local_impl,
+  vectorize.args = "file",
+  USE.NAMES = FALSE
+)
+
 rehash_local <- function(file, config) {
-  if (dir.exists(file)) {
-    rehash_dir(file, config)
-  } else {
-    rehash_file(file, config)
-  }
+  as.character(rehash_local_list(file, config))
 }
 
 rehash_dir <- function(dir, config) {
