@@ -4,4 +4,4 @@ Sys.setenv("drake_session_info" = "false")
 library(testthat)
 library(drake)
 
-test_check("drake")
+test_check("drake", reporter = "summary")
