@@ -1,5 +1,19 @@
 drake_context("analysis")
 
+test_with_dir("drake_validate.drake_deps() (#1183)", {
+  x <- new_drake_deps()
+  expect_silent(drake_validate(x))
+  x$globals <- NULL
+  expect_error(drake_validate(x))
+})
+
+test_with_dir("drake_validate.drake_deps_ht() (#1183)", {
+  x <- new_drake_deps_ht()
+  expect_silent(drake_validate(x))
+  x$globals <- NULL
+  expect_error(drake_validate(x))
+})
+
 test_with_dir("busy function", {
   f <- function(a = 1, b = k(i), nineteen, string_args = c("sa1", "sa2")) {
     for (iter in 1:10) {
@@ -31,8 +45,8 @@ test_with_dir("busy function", {
     Quote(quoted2)
     expression(quoted3)
   }
-  out <- analyze_code(f)
-  out <- decode_deps_list(out)
+  out <- drake_deps(f)
+  out <- select_nonempty(decode_deps_list(out))
   expect_equal(sort(out$file_in), sort(c("x", "y")))
   expect_equal(sort(out$file_out), sort(c("w", "z")))
   str <- sort(
@@ -54,7 +68,7 @@ test_with_dir("busy function", {
 test_with_dir("equals analysis", {
   for (text in c("z = g(a * b)", "function(x) {z = g(a * b)}")) {
     expr <- parse(text = text)
-    out <- analyze_code(expr)
+    out <- drake_deps(expr)
     expect_equal(sort(out$globals), sort(c("a", "b", "g")))
   }
 })
@@ -65,7 +79,7 @@ test_with_dir("local variable tests from the codetools package", {
     if (!is.function(expr) && !is.language(expr)) {
       return(list())
     }
-    results <- new_code_analysis_results()
+    results <- new_drake_deps_ht()
     locals <- ht_new()
     walk_code(expr, results, locals, NULL)
     ht_list(locals)
@@ -81,30 +95,30 @@ test_with_dir("local variable tests from the codetools package", {
 
 test_with_dir("same tests with global variables", {
   code <- quote(x <- 1)
-  expect_equal(as.character(analyze_code(code)$globals), character(0))
+  expect_equal(as.character(drake_deps(code)$globals), character(0))
   code <- quote(x <- y <- 1)
-  expect_equal(as.character(analyze_code(code)$globals), character(0))
+  expect_equal(as.character(drake_deps(code)$globals), character(0))
   code <- quote(local(x <- 1))
-  expect_equal(analyze_code(code)$globals, "local")
+  expect_equal(drake_deps(code)$globals, "local")
   code <- quote(assign(x, 3))
-  out <- sort(analyze_code(code)$globals)
+  out <- sort(drake_deps(code)$globals)
   expect_equal(out, sort(c("assign", "x")))
   code <- quote({
     assign(x, 3)
     x <- 1
   })
-  out <- sort(analyze_code(code)$globals)
+  out <- sort(drake_deps(code)$globals)
   expect_equal(out, sort(c("assign", "x")))
   code <- quote({
     x <- 1
     assign(x, 3)
   })
-  expect_equal(analyze_code(code)$globals, "assign")
+  expect_equal(drake_deps(code)$globals, "assign")
   code <- quote(assign("x", 3))
-  out <- sort(analyze_code(code)$globals)
+  out <- sort(drake_deps(code)$globals)
   expect_equal(out, "assign")
   code <- quote(assign("x", 3, 4))
-  out <- sort(analyze_code(code)$globals)
+  out <- sort(drake_deps(code)$globals)
   expect_equal(out, "assign")
 })
 
@@ -113,9 +127,9 @@ test_with_dir("solitary codetools globals tests", {
     local <- 1
     local(x <- 1)
   })
-  out <- as.character(analyze_code(code)$globals)
+  out <- as.character(drake_deps(code)$globals)
   expect_equal(out, character(0))
-  out <- analyze_code(quote(local(x <- 1, e)))$globals
+  out <- drake_deps(quote(local(x <- 1, e)))$globals
   expect_equal(sort(out), sort(c("local", "e")))
   f <- function() {
     if (is.R()) {
@@ -124,64 +138,64 @@ test_with_dir("solitary codetools globals tests", {
       y
     }
   }
-  out <- analyze_code(f)$globals
+  out <- drake_deps(f)$globals
   expect_equal(sort(out), sort(c("if", "is.R", "x", "y")))
   f <- function() {
     if (FALSE) {
       x
     }
   }
-  out <- analyze_code(f)$globals
+  out <- drake_deps(f)$globals
   expect_equal(sort(out), sort(c("if", "x")))
 
   f <- function(x) {z <- 1; x + y + z} # nolint
-  expect_equal(sort(analyze_code(f)$globals), "y")
-  expect_equal(analyze_code(function() Quote(x))$globals, "Quote")
+  expect_equal(sort(drake_deps(f)$globals), "y")
+  expect_equal(drake_deps(function() Quote(x))$globals, "Quote")
   f <- function(f, x, y) {
     local <- f
     local(x <- y)
     x
   }
-  expect_equivalent(analyze_code(f), list())
+  expect_equivalent(drake_deps(f), new_drake_deps())
   f <- function() {
     x <- 1; y <- 2
   }
-  out <- as.character(analyze_code(f)$globals)
+  out <- as.character(drake_deps(f)$globals)
   expect_equal(out, character(0))
   f <- function(u = x <- 1) {
     y <- 2
   }
-  expect_equal(as.character(analyze_code(f)$globals), character(0))
+  expect_equal(as.character(drake_deps(f)$globals), character(0))
 })
 
 # https://github.com/cran/codetools/blob/9bac1daaf19a36bd03a2cd7d67041893032e7a04/R/codetools.R#L302-L365 # nolint
 # https://cran.r-project.org/doc/manuals/R-lang.html#Subset-assignment
 test_with_dir("replacement functions", {
   code <- quote(f(x) <- 1)
-  out <- sort(analyze_code(code)$globals)
+  out <- sort(drake_deps(code)$globals)
   expect_equal(out, sort(c("f<-", "x")))
 
   code <- quote({
     f(x) <- 1
     x <- 5
   })
-  out <- sort(analyze_code(code)$globals)
+  out <- sort(drake_deps(code)$globals)
   expect_equal(out, sort(c("f<-", "x")))
 
   code <- quote({
     x <- 5
     f(x) <- 1
   })
-  out <- analyze_code(code)$globals
+  out <- drake_deps(code)$globals
   expect_equal(out, "f<-")
 
   code <- quote(f(g(h(k(x)))) <- seven)
-  out <- sort(as.character(analyze_code(code)$globals))
+  out <- sort(as.character(drake_deps(code)$globals))
   exp <- sort(c("f<-", "g", "g<-", "h", "h<-", "k", "k<-", "x", "seven"))
   expect_equal(out, exp)
 
   code <- quote(f(g(h(x, w), y(a)), z(u, v)) <- 1)
-  out <- sort(as.character(analyze_code(code)$globals))
+  out <- sort(as.character(drake_deps(code)$globals))
   exp <- sort(
     c("f<-", "g", "g<-", "h", "h<-", "a", "u", "v", "w", "x", "y", "z")
   )
@@ -191,7 +205,7 @@ test_with_dir("replacement functions", {
     x <- 5
     f(g(h(x, w), y(a)), z(u, v)) <- 1
   })
-  out <- sort(as.character(analyze_code(code)$globals))
+  out <- sort(as.character(drake_deps(code)$globals))
   exp <- sort(
     c("f<-", "g", "g<-", "h", "h<-", "a", "u", "v", "w", "y", "z")
   )
@@ -201,15 +215,15 @@ test_with_dir("replacement functions", {
     f(g(h(x, w), y(a)), z(u, v)) <- 1
     x <- 5
   })
-  out <- sort(as.character(analyze_code(code)$globals))
+  out <- sort(as.character(drake_deps(code)$globals))
   exp <- sort(
     c("f<-", "g", "g<-", "h", "h<-", "a", "u", "v", "w", "x", "y", "z")
   )
   expect_equal(out, exp)
 
   code <- quote(f(base::g(pkg:::h(x, w), y(a)), z(u, v)) <- 1)
-  out <- analyze_code(code)
-  out <- decode_deps_list(out)
+  out <- drake_deps(code)
+  out <- select_nonempty(decode_deps_list(out))
   expect_equal(
     sort(out$globals),
     sort(c("f<-", "a", "u", "v", "x", "w", "y", "z"))
@@ -254,13 +268,13 @@ test_with_dir("character vectors inside language objects", {
     drake_config(plan, cache = storr::storr_environment(), session_info = FALSE)
   )
   expect_equal(
-    sort(analyze_code(plan$command[[1]])$strings),
+    sort(drake_deps(plan$command[[1]])$strings),
     sort(c("a", "b"))
   )
 })
 
 test_with_dir("dollar sign (#938)", {
-  expect_equal(analyze_code(quote(x$y))$globals, "x")
+  expect_equal(drake_deps(quote(x$y))$globals, "x")
   f <- function(target, cache) {
     exists <- cache$exists(key = target) && (
       imported <- diagnose(
@@ -271,7 +285,7 @@ test_with_dir("dollar sign (#938)", {
         FALSE
     )
   }
-  out <- sort(analyze_code(f)$globals)
+  out <- sort(drake_deps(f)$globals)
   exp <- sort(c("diagnose", "%||%"))
   expect_equal(out, exp)
 })
@@ -417,7 +431,7 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
   file.copy(
     from = path, to = file.path(getwd(), "report.Rmd"), overwrite = TRUE)
   x <- cds_command_dependencies(cmd)
-  x <- decode_deps_list(x)
+  x <- select_nonempty(decode_deps_list(x))
   x0 <- list(
     file_in = "x", file_out = "y", loadd = "large",
     readd = c("small", "coef_regression2_small"),
@@ -427,7 +441,7 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
     expect_equal(sort(x[[i]]), sort(x0[[i]]))
   }
   y <- cds_import_dependencies(f)
-  y <- decode_deps_list(y)
+  y <- select_nonempty(decode_deps_list(y))
   y0 <- list(
     file_in = "x",
     knitr_in = "report.Rmd",
@@ -453,9 +467,12 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
 test_with_dir("deps_code() and deps_target_impl()", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   expect_equal(nrow(deps_code("")), 0)
-  expect_equal(length(cds_command_dependencies(NA)), 0)
-  expect_equal(length(cds_command_dependencies(NULL)), 0)
-  expect_equal(length(cds_command_dependencies(character(0))), 0)
+  expect_equal(length(select_nonempty(cds_command_dependencies(NA))), 0)
+  expect_equal(length(select_nonempty(cds_command_dependencies(NULL))), 0)
+  expect_equal(
+    length(select_nonempty(cds_command_dependencies(character(0)))),
+    0
+  )
   expect_equal(deps_code(base::c)$name, character(0))
   expect_equal(deps_code(base::list)$name, character(0))
   f <- function(x, y) {
@@ -948,11 +965,11 @@ test_with_dir("function_dependencies() works on :: and :::", {
       "triple:::triple"
     )
   )
-  cd <- analyze_code(crazy)
-  cd <- decode_deps_list(cd)
+  cd <- drake_deps(crazy)
+  cd <- select_nonempty(decode_deps_list(cd))
   expect_equal(sort(cd$namespaced), ns)
-  cd <- analyze_code(crazy)
-  cd <- decode_deps_list(cd)
+  cd <- drake_deps(crazy)
+  cd <- select_nonempty(decode_deps_list(cd))
   expect_equal(
     unname(sort(unlist(cd))),
     sort(c(ns, "g", "myfun1", "sqrt", "local"))
